Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ISvcBlockchainTxs ¶
type ISvcBlockchainTxs interface {
SrvInitLedger() ([]byte, *dto.Problem)
GetUserSvc(id string) (*dto.User, *dto.Problem)
ReadAssetSvc(id string) (interface{}, *dto.Problem)
CreateAssetSvc(asset dto.Asset) (interface{}, *dto.Problem)
UpdateAssetSvc(asset dto.Asset) (interface{}, *dto.Problem)
}
ISvcBlockchainTxs Blockchain transactions service interface
func NewSvcBlockchainTxs ¶
func NewSvcBlockchainTxs(pRepo *hlf.RepoBlockchain, reposUser *db.RepoUsers) ISvcBlockchainTxs
NewSvcBlockchainTxs instantiate the HLF blockchains transactions services
type ISvcHlfIdentity ¶
type SvcHlfIdentity ¶
type SvcHlfIdentity struct {
// contains filtered or unexported fields
}
func NewSvcHlfIdentity ¶
func NewSvcHlfIdentity(pRepoI *hlf.RepoHlfIdentity, pRepoU *db.RepoUsers) *SvcHlfIdentity
NewSvcHlfIdentity
func (*SvcHlfIdentity) MkDappIdentity ¶
func (s *SvcHlfIdentity) MkDappIdentity(forAdmin bool) *dto.Problem
MkDappIdentity creates the dapp identity to authenticate all the operations in the HLF network. Technically, import the cert and private key from and existing HLF identity previously created with a CA
Click to show internal directories.
Click to hide internal directories.